<?php

/**
 * @copyright (c) 2019.
 * @author            Alan Fuller (support@fullworks)
 * @licence           GPL V3 https://www.gnu.org/licenses/gpl-3.0.en.html
 * @link                  https://fullworks.net
 *
 * This file is part of a Fullworks Plugin.
 *
 *     This plugin is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This plugin is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with   Fullworks Security.  https://www.gnu.org/licenses/gpl-3.0.en.html
 *
 *
 */
namespace WidgetForEventbriteAPI\Includes {
    class Utilities
    {
        protected static  $instance ;
        private  $modal_setup = false ;
        private  $modal_id ;
        private  $modal_elements ;
        private  $plugin_name ;
        /**
         * Utilities constructor.
         */
        public function __construct()
        {
            $this->plugin_name = 'widget-for-eventbrite-api';
        }
        
        /**
         * @return Utilities
         */
        public static function get_instance()
        {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }
        
        private function format_display_price__premum_only( $prices )
        {
            if ( null === $prices->maximum_ticket_price ) {
                $prices->maximum_ticket_price = $prices->minimum_ticket_price;
            }
            
            if ( $prices->minimum_ticket_price->value == $prices->maximum_ticket_price->value ) {
                $price_display = sprintf( '%1$s%2$s', $this->get_currency_symbol__premium_only( $prices->minimum_ticket_price->currency ), $prices->minimum_ticket_price->major_value );
            } else {
                $price_display = sprintf(
                    '%1$s%2$s - %1$s%3$s',
                    $this->get_currency_symbol__premium_only( $prices->minimum_ticket_price->currency ),
                    $prices->minimum_ticket_price->major_value,
                    $prices->maximum_ticket_price->major_value
                );
            }
            
            /**
             * Filters the formatted display price.
             *
             * @param string $price_display formated output price.
             * @param number minimum_ticket_price lowest ticket price.
             * @param number maximum_ticket_price higest ticket price.
             * @param string currency currency code.
             *
             */
            return wp_kses_post( apply_filters(
                'wfea_price_display',
                $price_display,
                $prices->minimum_ticket_price->major_value,
                $prices->maximum_ticket_price->major_value,
                $prices->minimum_ticket_price->currency
            ) );
        }
        
        public function get_api_error_string( $error_string )
        {
            do {
                $error_string = $error_string->get_error_message();
            } while (is_wp_error( $error_string ));
            
            if ( is_array( $error_string ) ) {
                $text = json_decode( $error_string['body'] );
                
                if ( null !== $text ) {
                    $error_string = $text->error_description;
                } else {
                    if ( isset( $error_string['response'] ) ) {
                        $error_string = esc_html__( 'Error code from Eventbrite was' ) . ':' . $error_string['response']['code'] . ' ' . esc_html__( 'Error message' ) . ':' . $error_string['response']['message'];
                    }
                }
            
            }
            
            return $error_string;
        }
        
        public function get_cta( $args )
        {
            $cta = array();
            $type = 'available';
            $arg = explode( ',', $args['booknow_text'] );
            $cta['text'] = $arg[0];
            $cta['availability_class'] = 'event__available';
            $cta['class'] = ( isset( $arg[1] ) ? $arg[1] : 'book-now__link' );
            /**
             * @var \Freemius $wfea_fs Object for freemius.
             */
            global  $wfea_fs ;
            
            if ( 'completed' == get_post()->status || 'ended' == get_post()->status ) {
                $cta['availability_class'] = 'event__past';
                
                if ( $this->get_element( 'past_event_button', $args ) ) {
                    $type = 'event_completed';
                    $arg = explode( ',', $args['past_event_button'] );
                    $cta['text'] = $arg[0];
                    $cta['class'] = ( isset( $arg[1] ) ? $arg[1] : 'past_event__link disabled' );
                }
            
            }
            
            
            if ( 'started' == get_post()->status ) {
                $cta['availability_class'] = 'event__started';
                
                if ( $this->get_element( 'started_event_button', $args ) ) {
                    $type = 'event_started';
                    $arg = explode( ',', $args['started_event_button'] );
                    $cta['text'] = $arg[0];
                    $cta['class'] = ( isset( $arg[1] ) ? $arg[1] : 'started_event__link' );
                }
            
            }
            
            $cta = apply_filters( 'wfea_cta', $cta, $type );
            $cta['text'] = wp_kses_post( $cta['text'] );
            $cta['class'] = esc_attr( $cta['class'] );
            $cta['availability_class'] = esc_attr( $cta['availability_class'] );
            return (object) $cta;
        }
        
        public function get_element( $key, $array )
        {
            if ( isset( $array[$key] ) ) {
                return $array[$key];
            }
            return false;
        }
        
        public function get_calendar_fields( $args )
        {
            $id = get_post()->ID;
            $location = $this->get_location_display__premium_only( $args );
            $description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
            $dtstart = get_post()->start->utc;
            $dtend = get_post()->end->utc;
            $summary = get_the_title();
            $url = get_post()->url;
            $fields = '<input type="hidden" id="location-' . esc_attr( $id ) . '" name="location" value="' . esc_attr( $location ) . '">';
            $fields .= '<input type="hidden" id="description-' . esc_attr( $id ) . '" name="description" value="' . esc_attr( $description ) . '">';
            $fields .= '<input type="hidden" id="dtstart-' . esc_attr( $id ) . '" name="dtstart" value="' . esc_attr( $dtstart ) . '">';
            $fields .= '<input type="hidden" id="dtend-' . esc_attr( $id ) . '" name="dtend" value="' . esc_attr( $dtend ) . '">';
            $fields .= '<input type="hidden" id="summary-' . esc_attr( $id ) . '" name="summary" value="' . esc_attr( $summary ) . '">';
            $fields .= '<input type="hidden" id="url-' . esc_attr( $id ) . '" name="url" value="' . esc_attr( $url ) . '">';
            return $fields;
        }
        
        public function get_fb_share_href( $args )
        {
            global  $wp ;
            return 'https://www.facebook.com/sharer/sharer.php?u=' . urlencode( home_url( $wp->request ) );
        }
        
        public function get_twitter_share_href( $args )
        {
            global  $wp ;
            return 'https://twitter.com/intent/tweet?text=' . urlencode( get_the_title() . ' ' . wfea_event_time( $args ) . ' ' . home_url( $wp->request ) );
        }
        
        public function get_gcal_href( $args )
        {
            $id = get_post()->ID;
            $location = $this->get_location_display__premium_only( $args );
            $description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
            $summary = get_the_title();
            $url = get_post()->url;
            $gCalLink = 'https://calendar.google.com/calendar/render?action=TEMPLATE&text=' . rawurlencode( esc_attr( $summary ) ) . '&dates=' . gmdate( "Ymd", strtotime( get_post()->start->local ) ) . 'T' . gmdate( "His", strtotime( get_post()->start->local ) ) . 'Z' . '/' . (( get_post()->end->local ? gmdate( "Ymd", strtotime( get_post()->end->local ) ) . "T" . gmdate( "His", strtotime( get_post()->end->local ) ) . "Z" : gmdate( "Ymd", strtotime( get_post()->start->start ) + 60 * 60 * 3 ) . "T" . gmdate( "His", strtotime( get_post()->start->local ) + 60 * 60 ) . "Z" )) . '&details=' . rawurlencode( $url ) . ' ' . rawurlencode( $description ) . '&location=' . rawurlencode( $location ) . '&trp=false&sprop=' . rawurlencode( $url ) . '&sprop=name:' . rawurlencode( get_bloginfo( 'name' ) );
            return $gCalLink;
        }
        
        public function get_yahoo_href( $args )
        {
            // https://calendar.yahoo.com/?v=60&view=d&type=20&title=Monday+Coffee+Chat&st=20211005T083000Z&dur=0300&desc=For+details%2C+go+here%3A%0Ahttps%3A%2F%2Fwww.eventbrite.co.uk%2Fe%2Fmonday-coffee-chat-tickets-153712946561&in_loc=
            $id = get_post()->ID;
            $location = $this->get_location_display__premium_only( $args );
            $description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
            $summary = get_the_title();
            $et = '';
            if ( get_post()->end->local ) {
                $et = '&et=' . gmdate( "Ymd", strtotime( get_post()->end->local ) ) . "T" . gmdate( "His", strtotime( get_post()->end->local ) ) . "Z";
            }
            $url = get_post()->url;
            $yahoolink = 'https://calendar.yahoo.com/?v=60&view=d&type=20&title=' . urlencode( esc_attr( get_post()->post_title ) ) . '&st=' . gmdate( "Ymd", strtotime( get_post()->start->local ) ) . 'T' . gmdate( "His", strtotime( get_post()->start->local ) ) . 'Z' . $et . '&desc=' . rawurlencode( $url ) . ' ' . rawurlencode( $description ) . '&in_loc=' . rawurlencode( $location );
            return $yahoolink;
        }
        
        public function get_outlook_cal_href( $args )
        {
            //<a href="https://bay02.calendar.live.com/calendar/calendar.aspx?rru=addevent&dtstart=20151119T140000Z&dtend=20151119T160000Z&summary=Summary+of+the+event&location=Location+of+the+event&description=example+text.&allday=false&uid=">add to Outlook calendar</a>
            $location = $this->get_location_display__premium_only( $args );
            $description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
            $summary = get_the_title();
            $url = get_post()->url;
            $href = 'https://outlook.live.com/calendar/calendar.aspx?rru=addevent&dtstart=' . gmdate( "Ymd", strtotime( get_post()->start->local ) ) . 'T' . gmdate( "His", strtotime( get_post()->start->local ) ) . 'Z' . '&dtend=' . (( get_post()->end->local ? gmdate( "Ymd", strtotime( get_post()->end->local ) ) . "T" . gmdate( "His", strtotime( get_post()->end->local ) ) . "Z" : gmdate( "Ymd", strtotime( get_post()->start->start ) + 60 * 60 * 3 ) . "T" . gmdate( "His", strtotime( get_post()->start->local ) + 60 * 60 ) . "Z" )) . '&summary=' . rawurlencode( esc_attr( $summary ) ) . '&location=' . rawurlencode( esc_attr( $location ) ) . '&description=' . rawurlencode( esc_attr( $description ) ) . '&allday=false&uid=';
            return $href;
        }
        
        public function get_yahoo_cal_href( $args )
        {
            //<a href="https://calendar.yahoo.com/?v=60&view=d&type=20&title=Summary+of+the+event&st=20151119T090000&et=20151119T110000&desc=example+text.%0A%0AThis+is+the+text+entered+in+the+event+description+field.&in_loc=Location+of+the+event&uid=">add to Yahoo calendar</a>
        }
        
        public function get_booknow_link( $args )
        {
            return $this->format_booknow_link( $args, get_post()->url );
        }
        
        /**
         * @param $args
         *
         * @return mixed|void  either  false or the ID of the popup
         */
        public function is_popup_allowed( $args )
        {
            if ( !isset( $args['popup'] ) || !$args['popup'] ) {
                return apply_filters( 'wfea_is_popup_allowed', false, $args );
            }
            /**
             * @var \Freemius $wfea_fs Object for freemius.
             */
            global  $wfea_fs ;
            return apply_filters( 'wfea_is_popup_allowed', get_post()->ID, $args );
        }
        
        public function get_original_booknow_link( $args )
        {
            return $this->format_booknow_link( $args, get_post()->eb_url );
        }
        
        private function format_booknow_link( $args, $url )
        {
            $ext = ( $this->get_element( 'tickets', $args ) ? '#tickets' : '' );
            $link = 'href="' . esc_url( $url ) . $ext . '"';
            global  $wfea_fs ;
            return $link;
        }
        
        public function get_section_attrs( $data )
        {
            return sprintf(
                '%1$s class="wfea %2$s %3$s %4$s %5$s %6$s"',
                ( !empty($this->get_element( 'cssid', $data->args )) ? 'id="' . esc_attr( $this->get_element( 'cssid', $data->args ) ) . '"' : '' ),
                ( !empty($this->get_element( 'css_class', $data->args )) ? '' . esc_attr( $this->get_element( 'css_class', $data->args ) ) . '' : '' ),
                ( !empty($this->get_element( 'style', $data->args )) ? '' . esc_attr( $this->get_element( 'style', $data->args ) ) . '' : '' ),
                ( !empty($data->template) ? '' . esc_attr( $data->template ) . '' : '' ),
                esc_attr( $data->event->layout_class ),
                esc_attr( $data->event->layout_name )
            );
        }
        
        public function register_template_dirs( $dir )
        {
            add_filter( 'widget-for-eventbrite-api_template_paths', function ( $file_paths ) use( $dir ) {
                //  put this path as first so it will always override others template parts of the same name
                array_unshift( $file_paths, trailingslashit( $dir ) . 'templates/parts' );
                array_unshift( $file_paths, trailingslashit( $dir ) . 'templates/loops' );
                array_unshift( $file_paths, trailingslashit( $dir ) . 'templates' );
                return $file_paths;
            }, 90 );
        }
    
    }
}
//global namespace
namespace {
    // legacy function used in templates
    // don't add to this add to class
    if ( !function_exists( 'eventbrite_event_eb_url' ) ) {
        /**
         * Give the URL to an event's public viewing page on eventbrite.com.
         *
         * @return string URL on eventbrite.com
         */
        function eventbrite_event_eb_url( $ext = null )
        {
            return get_post()->url . $ext;
        }
    
    }
    if ( !function_exists( 'eventbrite_event_start' ) ) {
        /**
         * Give access to the current event's start time: timezone, local, utc
         *
         * @return object Start time properties
         */
        function eventbrite_event_start()
        {
            return apply_filters( 'wfea_eventbrite_event_start', get_post()->start );
        }
    
    }
    if ( !function_exists( 'eventbrite_event_end' ) ) {
        /**
         * Give access to the current event's end time: timezone, local, utc
         *
         * @return object End time properties
         */
        function eventbrite_event_end()
        {
            return apply_filters( 'wfea_eventbrite_event_end', get_post()->end );
        }
    
    }
    if ( !function_exists( 'eventbrite_event_time' ) ) {
        function eventbrite_event_time()
        {
            return apply_filters( 'wfea_eventbrite_event_time', wfea_event_time() );
        }
    
    }
    if ( !function_exists( 'wfea_door_time' ) ) {
        function wfea_door_time( $args = false )
        {
            return 'door';
        }
    
    }
    if ( !function_exists( 'wfea_event_time' ) ) {
        /**
         * Return an event's time.
         *
         * @return string Event time.
         */
        function wfea_event_time( $args = false )
        {
            // Collect our formats from the admin.
            $date_format = apply_filters( 'wfea_combined_date_time_date_format', get_option( 'date_format' ) . ', ' );
            $time_format = apply_filters( 'wfea_combined_date_time_time_format', get_option( 'time_format' ) );
            $combined_format = $date_format . $time_format;
            
            if ( false == $args || $args['show_end_time'] ) {
                // Determine if the end time needs the date included (in the case of multi-day events).
                $end_time = ( eventbrite_is_multiday_event() ? mysql2date( $combined_format, eventbrite_event_end()->local ) : mysql2date( $time_format, eventbrite_event_end()->local ) );
            } else {
                $end_time = '';
            }
            
            // Assemble the full event time string.
            $event_time = sprintf(
                _x( '%1$s %3$s %2$s', 'Event date and time. %1$s = start time, %2$s = end time %3$s is a separator', 'eventbrite_api' ),
                esc_html( mysql2date( $combined_format, eventbrite_event_start()->local ) ),
                esc_html( $end_time ),
                ( empty($end_time) ? '' : '-' )
            );
            return apply_filters(
                'wfea_event_time',
                $event_time,
                eventbrite_event_start(),
                eventbrite_event_end()
            );
        }
    
    }
    if ( !function_exists( 'eventbrite_is_multiday_event' ) ) {
        /**
         * Determine if an event spans multiple calendar days.
         *
         * @return bool True if start and end date are the same, false otherwise.
         */
        function eventbrite_is_multiday_event()
        {
            // Set date variables for comparison.
            $start_date = mysql2date( 'Ymd', eventbrite_event_start()->local );
            $end_date = mysql2date( 'Ymd', eventbrite_event_end()->local );
            // Return true if they're different, false otherwise.
            return $start_date !== $end_date;
        }
    
    }
    if ( !function_exists( 'wfea_get_ticket_form_widget_height' ) ) {
        function wfea_get_ticket_form_widget_height()
        {
            return 400;
            // backward compatibility for custom templates
        }
    
    }
}